# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-CPAN-Changes
Summary:	Read and write Changes files
Version:	0.500004
Release:	1.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/CPAN-Changes
Source0:	https://cpan.metacpan.org/modules/by-module/CPAN/CPAN-Changes-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Module::Runtime)
BuildRequires:	perl(Moo) >= 1.006000
BuildRequires:	perl(Moo::Role)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Quote) >= 1.005000
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Types::Standard)
BuildRequires:	perl(version)
BuildRequires:	perl(warnings)
# Script Runtime
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(Pod::Usage)
# Test Suite
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
BuildRequires:	perl(Test::Differences)
# Extra Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage::TrustMe) => 0.002000
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
It is standard practice to include a Changes file in your distribution. The
purpose of the Changes file is to help a user figure out what has changed
since the last release.

People have devised many ways to write the Changes file. A preliminary
specification has been created (CPAN::Changes::Spec) to encourage module
authors to write clear and concise Changes.

This module will help users programmatically read and write Changes files
that conform to the specification.

%prep
%setup -q -n CPAN-Changes-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{_bindir}/tidy_changelog
%{perl_vendorlib}/CPAN/
%{perl_vendorlib}/Test/
%{_mandir}/man1/tidy_changelog.1*
%{_mandir}/man3/CPAN::Changes.3*
%{_mandir}/man3/CPAN::Changes::Entry.3*
%{_mandir}/man3/CPAN::Changes::Group.3*
%{_mandir}/man3/CPAN::Changes::Parser.3*
%{_mandir}/man3/CPAN::Changes::Release.3*
%{_mandir}/man3/CPAN::Changes::Spec.3*
%{_mandir}/man3/Test::CPAN::Changes.3*

%changelog
* Fri May  3 2024 Paul Howarth <paul@city-fan.org> - 0.500004-1
- Update to 0.500004
  - Fix tests on Windows

* Fri Feb 23 2024 Paul Howarth <paul@city-fan.org> - 0.500003-1
- Update to 0.500003
  - Fix calling ->name on an unnamed group
  - Fix ->set_changes call on groups

* Thu Oct 26 2023 Paul Howarth <paul@city-fan.org> - 0.500002-1
- Update to 0.500002
  - Full rewrite
    - The new version can parse nested entries to an arbitrary depth, rather
      than just groups
    - It can parse many more formats, and can format the outputs more flexibly;
      this means it can better handle the change logs that actually exist on
      CPAN
  - Parsed releases keep their original order
  - Pass given ChangeLog filename for --check
- Package LICENSE file

* Wed Mar  8 2023 Paul Howarth <paul@city-fan.org> - 0.400002-23
- Use SPDX-format license tag

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 0.400002-11
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop support for building with Test::More < 0.96
  - Drop legacy BuildRoot: and Group: tags

* Thu Aug 11 2016 Paul Howarth <paul@city-fan.org> - 0.400002-3
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 0.400002-1
- Update to 0.400002
  - Revert whitespace changes that were inadvertently included in previous
    release
  - Escape curly brackets in test to avoid warning in perl 5.22

* Fri Jun 19 2015 Paul Howarth <paul@city-fan.org> - 0.400001-3
- Perl 5.22 rebuild

* Tue May 26 2015 Paul Howarth <paul@city-fan.org> - 0.400001-1
- Update to 0.400001
  - Accept either UTF-8 or ISO-8859-1 files and decode them
  - Only treat bracketed text if it is on its own line with no other brackets
  - Bump version.pm prereq to make sure it works properly
  - Let long tokens (like URLs) overflow rather than splitting them into
    multiple lines
  - Don't wrap on non-breaking spaces
  - Clean up packaging
  - Return undef for dates or notes that don't exist
  - Quote meta chars to fix a problem that clobbered dates with timezones due
    to the '+' char (GH #20)
- This release by HAARG → update source URL
- Classify buildreqs by usage
- Update patch for building with Test::More < 0.96

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.30-3
- Perl 5.20 rebuild

* Wed Aug 27 2014 Paul Howarth <paul@city-fan.org> - 0.30-2
- Don't BR: perl(Moo) when bootstrapping

* Mon Jul 28 2014 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30:
  - Fix for subclassing CPAN::Changes::Group (GH #23)

* Thu Jul 24 2014 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29:
  - Groups are now objects (CPAN::Changes::Group); backwards compatibility
    from hashes should be preserved (GH #22)

* Thu Jun 12 2014 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28:
  - Add "SEE ALSO" links to similar modules (CPAN RT#94636)
  - Use perl 5.8-compatible regex

* Sat Dec 14 2013 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27:
  - Bump spec version to 0.04
  - Allow non-"word" characters between a Version and a Date

* Fri Nov 22 2013 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26:
  - Fix reference issues when adding a release (CPAN RT#90605)

* Wed Oct  9 2013 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25:
  - Fix Dist::Zilla date parsing: now puts timezone data in note section
    (Github #17)
  - Move Text::Wrap usage to proper module
  - Typo fix

* Thu Aug 15 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23:
  - Bump spec version to 0.03
  - Be more strict about what we consider to be a Dist::Zilla-style date
    to avoid false positive matches
  - Update W3CDTF parsing to make the "T" marker optional (CPAN RT#87499)
  - Fix extra whitespace for empty values after version (CPAN RT#87524)

* Tue Jul 30 2013 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22:
  - Sync module versions (CPAN RT#87455)

* Tue Jul 30 2013 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21:
  Spec Changes:
  - Bump version to 0.02
  - Added "unknown/dev" release date options (CPAN RT#67705)
  - Added optional release note (CPAN RT#69321)
  - Added another preamble example
  - Added a note about line length
  Code Changes:
  - Require Test::More 0.96 (CPAN RT#84994)
  - Added --check and --help flags to tidy_changelog script
  - Properly parse multi-line preamble
  - Test::CPAN::Changes now warns about parsed dates not in spec-compliant form
  - Handle unknown/dev release dates and release note from new spec
- BR: perl(Pod::Usage)

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 0.20-2
- Perl 5.18 rebuild

* Thu May  2 2013 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20:
  - 'delete_empty_groups' shouldn't erronously delete default group
  - Add tidy_changelog utility script
  - Minor pod fix
- Add patch to support building with Test::More < 0.96 (CPAN RT#84994)

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 0.19-2
- BR: perl(Cwd), perl(File::Path), perl(Scalar::Util) and perl(Test::Builder)

* Tue May  1 2012 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19:
  - Test::CPAN::Changes now accepts version entries ending in '-TRIAL'
    (CPAN RT#76882)
  - releases() in CPAN::Changes also accepts entries ending in '-TRIAL'
- Don't need to remove empty directories from buildroot
- Drop %%defattr, redundant since rpm 4.4

* Tue Oct 18 2011 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18:
  - Expand changes_file_ok() to accept arguments so that a specific version may
    be checked
  - Add $VERSION to Test::CPAN::Changes so it plays nice with the toolchain
    e.g. Module::Install::AuthorRequires

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 0.17-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Apr 21 2011 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17:
  - Eliminate extra whitespace when release data is not defined (CPAN RT#67441)
  - Require version.pm 0.79, which introduced the $LAX regexp (CPAN RT#67613)
  - Add the option to sort groups

* Wed Apr 20 2011 Paul Howarth <paul@city-fan.org> - 0.16-1
- Initial RPM version
